%global _build_id_links none
%global sname citus
%global llvm 1
%global pgmajorversion 16

Summary:	PostgreSQL extension that transforms Postgres into a distributed database
Name:       %{sname}_%{pgmajorversion}
Version:	12.1.2
Release:	1%{dist}
License:	AGPLv3
URL:        https://github.com/citusdata/%{sname}
Source0:	https://github.com/citusdata/%{sname}/archive/v%{version}.tar.gz

BuildRequires:  make gcc
BuildRequires:	postgresql%{pgmajorversion}-private-devel
BuildRequires:	postgresql%{pgmajorversion}-server-devel
BuildRequires:  lz4-devel
BuildRequires:	libxslt-devel openssl-devel pam-devel readline-devel
BuildRequires:	libcurl-devel libzstd-devel libxml2-devel
Requires:	postgresql%{pgmajorversion}-server
Requires:	libzstd

%description
Citus horizontally scales PostgreSQL across commodity servers
using sharding and replication. Its query engine parallelizes
incoming SQL queries across these servers to enable real-time
responses on large datasets.

Citus extends the underlying database rather than forking it,
which gives developers and enterprises the power and familiarity
of a traditional relational database. As an extension, Citus
supports new PostgreSQL releases, allowing users to benefit from
new features while maintaining compatibility with existing
PostgreSQL tools. Note that Citus supports many (but not all) SQL
commands.

%package devel
Summary:	Citus development header files and libraries
Requires:	%{name} = %{version}-%{release}

%description devel
This package includes development libraries for Citus.

%if %llvm
%package llvmjit
Summary:	Just-in-time compilation support for Citus
Requires:	%{name} = %{version}-%{release}
# Packages come from Appstream:
BuildRequires:	llvm-devel <= 17.0.6-2 clang-devel >= 8.0.1

%description llvmjit
This packages provides JIT support for Citus
%endif

%prep
%setup -q -n %{sname}-%{version}

%build
%configure PG_CONFIG=%{_bindir}/pg_server_config
make %{?_smp_mflags}

%install
%make_install
# Install documentation with a better name:
%{__mkdir} -p %{buildroot}/doc/extension
%{__cp} README.md %{buildroot}/doc/extension/README-%{sname}.md

%files
%doc CHANGELOG.md
%license LICENSE
%doc /doc/extension/README-%{sname}.md
%{_libdir}/pgsql/%{sname}.so
%{_libdir}/pgsql/%{sname}_columnar.so
%{_libdir}/pgsql/%{sname}_pgoutput.so
%{_libdir}/pgsql/%{sname}_wal2json.so
%dir %{_libdir}/pgsql/%{sname}_decoders/
%{_libdir}/pgsql/%{sname}_decoders/pgoutput.so
%{_libdir}/pgsql/%{sname}_decoders/wal2json.so
%{_datadir}/pgsql/extension/%{sname}-*.sql
%{_datadir}/pgsql/extension/%{sname}.control
%{_datadir}/pgsql/extension/%{sname}_columnar-*.sql
%{_datadir}/pgsql/extension/columnar-*.sql
%{_datadir}/pgsql/extension/%{sname}_columnar.control

%files devel
%{_includedir}/pgsql/server/citus_version.h
%{_includedir}/pgsql/server/distributed/*.h

%if %llvm
%files llvmjit
    %{_libdir}/pgsql/bitcode/%{sname}*.bc
    %{_libdir}/pgsql/bitcode/%{sname}/*.bc
    %{_libdir}/pgsql/bitcode/%{sname}/*/*.bc
    %{_libdir}/pgsql/bitcode/%{sname}_columnar/*
    %{_libdir}/pgsql/bitcode/%{sname}_pgoutput/*
    %{_libdir}/pgsql/bitcode/%{sname}_wal2json/*
%endif

%changelog
* Fri Apr 12 2024 Wang Guodong <gordonwwang@tencent.com> - 12.1.2-1
- init build
